@@ -443,9 +443,7 @@ def serve(ctx, path, host, port, use_tunnel, reload, use_venv):
                 str(port),
                 "--factory",
             ]
-            + ["--reload"]
-            if reload
-            else [],
+            + (["--reload"] if reload else []),
             env=agent_env,
             cwd=agent_dir or None,
         ).check_returncode()
