@@ -3,7 +3,6 @@ from fixieai.client.client import get_agents
 from fixieai.client.client import get_client
 from fixieai.client.client import get_embeds
 from fixieai.client.client import query
-from fixieai.client.console import Console
 
 __all__ = [
     "FixieClient",
@@ -11,5 +10,4 @@ __all__ = [
     "get_client",
     "get_embeds",
     "query",
-    "Console",
 ]
